==> xlniuxdata-vipgame-1.0.65-20160628.033436-5-sources.jar: com/xunlei/niux/data/vipgame/vo/mobile/MobilegameCurrencyTransAudit.java <==
package com.xunlei.niux.data.vipgame.vo.mobile;

import com.ferret.common.dao.annotation.Table;

/**
 * Created by lizeyu on 2016/5/3.
 */
@Table(tableName="mobilegame_currency_transaudit",pkFieldName="seqid",pkFieldAssign=false)
public class MobilegameCurrencyTransAudit{

    private Long seqid;
    private String userId;
    private String bankNo;
    private String bankName;
    private Double remitMoney;
    private String remitTime;
    private Integer status; //状态 1,待发邮件；2,待审批；3,审批通过;4,审批不通过
    private String creater;
    private String createTime;
    private String createEmail;
    private String auditer;
    private String auditTime;
    private String auditEmail;
    private Integer transNiub;

    public Long getSeqid(){
        return seqid;
    }

    public void setSeqid(Long seqid){
        this.seqid = seqid;
    }

    public String getUserId(){
        return userId;
    }

    public void setUserId(String userId){
        this.userId = userId;
    }

    public String getBankNo(){
        return bankNo;
    }

    public void setBankNo(String bankNo){
        this.bankNo = bankNo;
    }

    public String getBankName(){
        return bankName;
    }

    public void setBankName(String bankName){
        this.bankName = bankName;
    }

    public Double getRemitMoney(){
        return remitMoney;
    }

    public void setRemitMoney(Double remitMoney){
        this.remitMoney = remitMoney;
    }

    public String getRemitTime(){
        return remitTime;
    }

    public void setRemitTime(String remitTime){
        this.remitTime = remitTime;
    }

    public Integer getStatus(){
        return status;
    }

    public void setStatus(Integer status){
        this.status = status;
    }

    public String getCreater(){
        return creater;
    }

    public void setCreater(String creater){
        this.creater = creater;
    }

    public String getCreateTime(){
        return createTime;
    }

    public void setCreateTime(String createTime){
        this.createTime = createTime;
    }

    public String getCreateEmail(){
        return createEmail;
    }

    public void setCreateEmail(String createEmail){
        this.createEmail = createEmail;
    }

    public String getAuditer(){
        return auditer;
    }

    public void setAuditer(String auditer){
        this.auditer = auditer;
    }

    public String getAuditTime(){
        return auditTime;
    }

    public void setAuditTime(String auditTime){
        this.auditTime = auditTime;
    }

    public String getAuditEmail(){
        return auditEmail;
    }

    public void setAuditEmail(String auditEmail){
        this.auditEmail = auditEmail;
    }

    public Integer getTransNiub(){
        return transNiub;
    }

    public void setTransNiub(Integer transNiub){
        this.transNiub = transNiub;
    }
}

==> xlniuxdata-vipgame-1.0.65-20161206.063133-42-sources.jar: com/xunlei/niux/data/vipgame/vo/mobile/MobilegameCurrencyTransAudit.java <==
package com.xunlei.niux.data.vipgame.vo.mobile;

import com.ferret.common.dao.annotation.Table;

/**
 * Created by lizeyu on 2016/5/3.
 */
@Table(tableName="mobilegame_currency_transaudit",pkFieldName="seqid",pkFieldAssign=false)
public class MobilegameCurrencyTransAudit{

    private Long seqid;
    private String userId;
    private String bankNo;
    private String bankName;
    private Double remitMoney;
    private String remitTime;
    private Integer status; //状态 1,待发邮件；2,待审批；3,审批通过;4,审批不通过
    private String creater;
    private String createTime;
    private String createEmail;
    private String auditer;
    private String auditTime;
    private String auditEmail;
    private Integer transNiub;
    private String remark;

    public Long getSeqid(){
        return seqid;
    }

    public void setSeqid(Long seqid){
        this.seqid = seqid;
    }

    public String getUserId(){
        return userId;
    }

    public void setUserId(String userId){
        this.userId = userId;
    }

    public String getBankNo(){
        return bankNo;
    }

    public void setBankNo(String bankNo){
        this.bankNo = bankNo;
    }

    public String getBankName(){
        return bankName;
    }

    public void setBankName(String bankName){
        this.bankName = bankName;
    }

    public Double getRemitMoney(){
        return remitMoney;
    }

    public void setRemitMoney(Double remitMoney){
        this.remitMoney = remitMoney;
    }

    public String getRemitTime(){
        return remitTime;
    }

    public void setRemitTime(String remitTime){
        this.remitTime = remitTime;
    }

    public Integer getStatus(){
        return status;
    }

    public void setStatus(Integer status){
        this.status = status;
    }

    public String getCreater(){
        return creater;
    }

    public void setCreater(String creater){
        this.creater = creater;
    }

    public String getCreateTime(){
        return createTime;
    }

    public void setCreateTime(String createTime){
        this.createTime = createTime;
    }

    public String getCreateEmail(){
        return createEmail;
    }

    public void setCreateEmail(String createEmail){
        this.createEmail = createEmail;
    }

    public String getAuditer(){
        return auditer;
    }

    public void setAuditer(String auditer){
        this.auditer = auditer;
    }

    public String getAuditTime(){
        return auditTime;
    }

    public void setAuditTime(String auditTime){
        this.auditTime = auditTime;
    }

    public String getAuditEmail(){
        return auditEmail;
    }

    public void setAuditEmail(String auditEmail){
        this.auditEmail = auditEmail;
    }

    public Integer getTransNiub(){
        return transNiub;
    }

    public void setTransNiub(Integer transNiub){
        this.transNiub = transNiub;
    }

    public String getRemark(){
        return remark;
    }

    public void setRemark(String remark){
        this.remark = remark;
    }
}
